@@ -8,17 +8,17 @@ pub mod cli;
 pub mod compiler;
 pub mod frontend;
 
-
+#[cfg(debug_assertions)]
 fn dev() {
     // ast::run();
     // backend::run();
-    frontend::parser::dev();
+    // frontend::parser::dev();
     // frontend::ast::dev();
     // codegen::html::dev();
-    // let xs = frontend::run_highlighter(include_str!("../source.txt"));
-    // for x in xs {
-    //     println!("{:#?}", x);
-    // }
+    let xs = frontend::run_highlighter(include_str!("../source.txt"));
+    for x in xs {
+        println!("{:#?}", x);
+    }
 }
 
 fn main() {
